@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  *
  * This is a generic class that is used by both the proxy importer (for
  * outgoing messages) and our local importer (for incoming messages). Basically
@@ -248,7 +248,7 @@ class ImportChangesICS implements IImportChanges {
 
 		// check the sync interval
 		if ($this->cutoffdate !== false) {
-			SLog::Write(LOGLEVEL_DEBUG, sprintf("ImportChangesICS->isModificationAllowed('%s'): cut off date is: %s", $messageid, $this->cutoffdate));
+			SLog::Write(LOGLEVEL_DEBUG, sprintf("ImportChangesICS->isModificationAllowed('%s'): cut off date is: %s (%s)", $messageid, Utils::FormatDate($this->cutoffdate), $this->cutoffdate));
 			if (($this->contentClass == "Email" && !MAPIUtils::IsInEmailSyncInterval($this->store, $mapimessage, $this->cutoffdate)) ||
 				  ($this->contentClass == "Calendar" && !MAPIUtils::IsInCalendarSyncInterval($this->store, $mapimessage, $this->cutoffdate))) {
 				SLog::Write(LOGLEVEL_WARN, sprintf("ImportChangesICS->isModificationAllowed('%s'): Message in %s is outside the sync interval. Data not saved.", $messageid, $this->contentClass));
@@ -406,6 +406,12 @@ class ImportChangesICS implements IImportChanges {
 		}
 
 		if (mapi_importcontentschanges_importmessagechange($this->importer, $props, $flags, $mapimessage)) {
+			// grommunio-sync #113: workaround blocking notifications on this item
+			$sourcekeyprops = mapi_getprops($mapimessage, [PR_ENTRYID]);
+			if (isset($sourcekeyprops[PR_ENTRYID])) {
+				GSync::ReplyCatchMark(bin2hex($sourcekeyprops[PR_ENTRYID]));
+			}
+
 			$response = $this->mapiprovider->SetMessage($mapimessage, $message);
 			mapi_savechanges($mapimessage);
 
@@ -456,6 +462,8 @@ class ImportChangesICS implements IImportChanges {
 			// open the source message
 			$mapimessage = mapi_msgstore_openentry($this->store, $entryid);
 			$this->mapiprovider->PreDeleteMessage($mapimessage);
+			// grommunio-sync #113: workaround blocking notifications on this item
+			GSync::ReplyCatchMark(bin2hex($entryid));
 		}
 
 		// do a 'soft' delete so people can un-delete if necessary
@@ -507,13 +515,19 @@ class ImportChangesICS implements IImportChanges {
 			}
 			 */
 
+			// grommunio-sync #113: workaround blocking notifications on this item
+			$entryid = mapi_msgstore_entryidfromsourcekey($this->store, hex2bin($fsk), hex2bin($sk));
+			if ($entryid !== false) {
+				GSync::ReplyCatchMark(bin2hex($entryid));
+			}
+
 			$readstate = ["sourcekey" => hex2bin($sk), "flags" => $flags];
 
 			if (!mapi_importcontentschanges_importperuserreadstatechange($this->importer, [$readstate])) {
 				throw new StatusException(sprintf("ImportChangesICS->ImportMessageReadFlag('%s','%d'): Error setting read state: 0x%X", $id, $flags, mapi_last_hresult()), SYNC_STATUS_OBJECTNOTFOUND);
 			}
 		}
-		// yeah OL sucks - ZP-779
+		// yeah OL sucks
 		else {
 			if (!$fsk) {
 				throw new StatusException(sprintf("ImportChangesICS->ImportMessageReadFlag('%s','%d'): Error setting read state. The message is in another folder but id is unknown as no short folder id is available. Please remove your device states to fully resync your device. Operation ignored.", $id, $flags), SYNC_STATUS_OBJECTNOTFOUND);
@@ -567,7 +581,7 @@ class ImportChangesICS implements IImportChanges {
 		if (!$entryid || !$srcmessage) {
 			$code = SYNC_MOVEITEMSSTATUS_INVALIDSOURCEID;
 			$mapiLastHresult = mapi_last_hresult();
-			// if we move to the trash and the source message is not found, we can also just tell the mobile that we successfully moved to avoid errors (ZP-624)
+			// if we move to the trash and the source message is not found, we can also just tell the mobile that we successfully moved to avoid errors
 			if ($newfolder == GSync::GetBackend()->GetWasteBasket()) {
 				$code = SYNC_MOVEITEMSSTATUS_SUCCESS;
 			}
