@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  *
  * Several utility functions
  */
@@ -54,31 +54,24 @@ class Utils {
 	 * @return string the address string or null
 	 */
 	public static function BuildAddressString($street, $zip, $city, $state, $country) {
-		$out = "";
+		$out = $country ?? "";
 
-		if (isset($country) && $street != "") {
-			$out = $country;
-		}
-
-		$zcs = "";
-		if (isset($zip) && $zip != "") {
-			$zcs = $zip;
-		}
-		if (isset($city) && $city != "") {
+		$zcs = $zip ?? "";
+		if ($city != "") {
 			$zcs .= (($zcs) ? " " : "") . $city;
 		}
-		if (isset($state) && $state != "") {
+		if ($state != "") {
 			$zcs .= (($zcs) ? " " : "") . $state;
 		}
 		if ($zcs) {
 			$out = $zcs . "\r\n" . $out;
 		}
 
-		if (isset($street) && $street != "") {
+		if ($street != "") {
 			$out = $street . (($out) ? "\r\n\r\n" . $out : "");
 		}
 
-		return ($out) ? $out : null;
+		return $out ?? null;
 	}
 
 	/**
@@ -342,6 +335,11 @@ class Utils {
 	 * @return string truncated string
 	 */
 	public static function Utf8_truncate($string, $length, $htmlsafe = false) {
+		// skip empty strings
+		if (empty($string)) {
+			return "";
+		}
+
 		// make sure length is always an integer
 		$length = (int) $length;
 
@@ -350,7 +348,7 @@ class Utils {
 			$length = strlen($string) - 1;
 		}
 
-		// The intent is not to cut HTML tags in half which causes displaying issues (see ZP-1240).
+		// The intent is not to cut HTML tags in half which causes displaying issues.
 		// The used method just tries to cut outside of tags, without checking tag validity and closing tags.
 		if ($htmlsafe) {
 			$offset = 0 - strlen($string) + $length;
@@ -700,11 +698,8 @@ class Utils {
 		if ($bpTypes === false) {
 			return SYNC_BODYPREFERENCE_PLAIN;
 		}
-		// The best choice is RTF, then HTML and then MIME in order to save bandwidth
+		// The bettter choice is HTML and then MIME in order to save bandwidth
 		// because MIME is a complete message including the headers and attachments
-		if (in_array(SYNC_BODYPREFERENCE_RTF, $bpTypes)) {
-			return SYNC_BODYPREFERENCE_RTF;
-		}
 		if (in_array(SYNC_BODYPREFERENCE_HTML, $bpTypes)) {
 			return SYNC_BODYPREFERENCE_HTML;
 		}
